==> echobase-ui-2.5-sources.jar: fr/ifremer/echobase/ui/actions/workingDb/GetImportLogDetail.java <==
package fr.ifremer.echobase.ui.actions.workingDb;

/*
 * #%L
 * EchoBase :: UI
 * $Id: GetImportLogDetail.java 842 2013-08-15 10:53:16Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/echobase/tags/echobase-2.5/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/workingDb/GetImportLogDetail.java $
 * %%
 * Copyright (C) 2011 - 2012 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import fr.ifremer.echobase.entities.EchoBaseEntityEnum;
import fr.ifremer.echobase.entities.ImportLog;
import fr.ifremer.echobase.entities.ImportType;
import fr.ifremer.echobase.entities.data.Voyage;
import fr.ifremer.echobase.services.service.DbEditorService;
import fr.ifremer.echobase.services.service.DecoratorService;
import fr.ifremer.echobase.ui.actions.EchoBaseActionSupport;
import org.nuiton.topia.persistence.metadata.TableMeta;

import java.util.Map;

/**
 * Obtain details of a given {@link ImportLog}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class GetImportLogDetail extends EchoBaseActionSupport {

    private static final long serialVersionUID = 1L;

    protected String importLogId;

    public void setImportLogId(String importLogId) {
        this.importLogId = importLogId;
    }

    protected Map data;

    public Map<?, ?> getData() {
        return data;
    }

    @Override
    public String execute() throws Exception {

        TableMeta<EchoBaseEntityEnum> tableMeta =
                dbEditorService.getTableMeta(EchoBaseEntityEnum.ImportLog);
        data = dbEditorService.getData(tableMeta, importLogId);

        // decorate import type
        Map<String, String> importTypes = decoratorService.decorateEnums(ImportType.values());
        String importType = (String) data.get(ImportLog.PROPERTY_IMPORT_TYPE);
        data.put(ImportLog.PROPERTY_IMPORT_TYPE, importTypes.get(importType));

        // decorate foreign keys
        dbEditorService.decorateForeignKey(data, Voyage.class, ImportLog.PROPERTY_VOYAGE_ID, null);

        return SUCCESS;
    }

    //------------------------------------------------------------------------//
    //-- Injected objects                                                     //
    //------------------------------------------------------------------------//

    protected transient DbEditorService dbEditorService;

    public void setDbEditorService(DbEditorService dbEditorService) {
        this.dbEditorService = dbEditorService;
    }

    protected transient DecoratorService decoratorService;

    public void setDecoratorService(DecoratorService decoratorService) {
        this.decoratorService = decoratorService;
    }
}

==> echobase-ui-2.5.1-sources.jar: fr/ifremer/echobase/ui/actions/workingDb/GetImportLogDetail.java <==
package fr.ifremer.echobase.ui.actions.workingDb;

/*
 * #%L
 * EchoBase :: UI
 * $Id: GetImportLogDetail.java 910 2013-12-16 18:22:36Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/echobase/tags/echobase-2.5.1/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/workingDb/GetImportLogDetail.java $
 * %%
 * Copyright (C) 2011 - 2012 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import fr.ifremer.echobase.entities.EchoBaseEntityEnum;
import fr.ifremer.echobase.entities.ImportLog;
import fr.ifremer.echobase.entities.ImportType;
import fr.ifremer.echobase.entities.data.Voyage;
import fr.ifremer.echobase.services.service.DbEditorService;
import fr.ifremer.echobase.services.service.DecoratorService;
import fr.ifremer.echobase.services.service.WorkingDbPersistenceService;
import fr.ifremer.echobase.ui.actions.EchoBaseActionSupport;
import org.nuiton.topia.persistence.metadata.TableMeta;

import java.util.Map;

/**
 * Obtain details of a given {@link ImportLog}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class GetImportLogDetail extends EchoBaseActionSupport {

    private static final long serialVersionUID = 1L;

    protected String importLogId;

    public void setImportLogId(String importLogId) {
        this.importLogId = importLogId;
    }

    protected Map data;

    public Map<?, ?> getData() {
        return data;
    }

    @Override
    public String execute() throws Exception {

        TableMeta<EchoBaseEntityEnum> tableMeta =
                dbEditorService.getTableMeta(EchoBaseEntityEnum.ImportLog);
        data = dbEditorService.getData(tableMeta, importLogId);

        // decorate import type
        Map<String, String> importTypes = decoratorService.decorateEnums(ImportType.values());
        String importType = (String) data.get(ImportLog.PROPERTY_IMPORT_TYPE);
        data.put(ImportLog.PROPERTY_IMPORT_TYPE, importTypes.get(importType));

        // decorate foreign keys
        Voyage voyage = workingDbPersistenceService.getVoyage((String) data.get(ImportLog.PROPERTY_VOYAGE_ID));
        decoratorService.decorateForeignKey(data, ImportLog.PROPERTY_VOYAGE_ID, voyage, null);

        return SUCCESS;
    }

    //------------------------------------------------------------------------//
    //-- Injected objects                                                     //
    //------------------------------------------------------------------------//

    protected transient WorkingDbPersistenceService workingDbPersistenceService;

    public void setWorkingDbPersistenceService(WorkingDbPersistenceService workingDbPersistenceService) {
        this.workingDbPersistenceService = workingDbPersistenceService;
    }

    protected transient DbEditorService dbEditorService;

    public void setDbEditorService(DbEditorService dbEditorService) {
        this.dbEditorService = dbEditorService;
    }

    protected transient DecoratorService decoratorService;

    public void setDecoratorService(DecoratorService decoratorService) {
        this.decoratorService = decoratorService;
    }
}
